================
Database service
================

.. toctree::

   apache-mod-wsgi.rst
   get_started.rst
   install.rst
   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
   manual_install.rst
   dashboard.rst
   verify.rst
   next-steps.rst


The Database service (trove) provides cloud provisioning functionality
for database engines.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial <http://docs.openstack.org/#install-guides>`_.
